<?php
// DNS SERVER CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
dnsquery_configwizard_init();

function dnsquery_configwizard_init(){
	
	$name="dnsquery";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.1",
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => "Monitor a host or domain lookup/query via DNS.",
		CONFIGWIZARD_DISPLAYTITLE => "DNS Query",
		CONFIGWIZARD_FUNCTION => "dnsquery_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "community2.png",
		);
		
	register_configwizard($name,$args);
	}



function dnsquery_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="dnsquery";
	
	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
		
			$address=grab_array_var($inargs,"address","");
			
			$output='

	<div class="sectionTitle">Domain Name</div>
	
			
	<table>

	<tr>
	<td valign="top">
	<label>FQDN:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
	The fully qualified domain name you\'d like to monitor.<br><br>
	</td>
	</tr>

	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
			
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(have_value($address)==false)
				$errmsg[$errors++]="No address specified.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			
			$dnsserver=grab_array_var($inargs,"dnsserver");
			$dnsauthority=grab_array_var($inargs,"dnsauthority");

			$ha=@gethostbyaddr($address);
			if($ha=="")
				$ha=$address;
			$hostname=grab_array_var($inargs,"hostname",$ha);
			
			$ip=gethostbyname($hostname);
			
			$services_serial=grab_array_var($inargs,"services_serial");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
			if($services_serial!="")
				$services=unserialize(base64_decode($services_serial));
			else
				$services=grab_array_var($inargs,"services",array(
					"dns"=>"on",
					"dnsip"=>"on",
					));
			if($serviceargs_serial!="")
				$serviceargs=unserialize(base64_decode($serviceargs_serial));
			else
				$serviceargs=grab_array_var($inargs,"serviceargs",array(
					));
				
			//print_r($services);
			//print_r($services_serial);
			
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">

	<div class="sectionTitle">Query Information</div>
	
			
	<table>
	
	<tr>
	<td valign="top">
	<label>FQDN:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>IP Address:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="ip" id="ip" value="'.htmlentities($ip).'" class="textfield" /><br class="nobr" />
	The IP address associated with the FQDN.
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Host Name:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
	The name you\'d like to have associated with this FQDN.
	</td>
	</tr>
	
	</table>


	<div class="sectionTitle">DNS Query Options</div>
	
	<table>
	
	<tr>
	<td valign="top">
	<label>DNS Server:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="dnsserver" id="dnsserver" value="'.htmlentities($dnsserver).'" class="textfield" /><br class="nobr" />
	The IP address of the DNS server you\'d like to use for the query (optional).
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Authoritative Response:</label><br class="nobr" />
	</td>
	<td>
<input type="checkbox" class="checkbox" id="dnsauthority" name="dnsauthority" '.is_checked($dnsauthority,"on").'><br class="nobr" />
	Require the DNS server specified above to be authoritative for the query.
	</td>
	</tr>
	
	</table>

	<div class="sectionTitle">DNS Query Services</div>
	
	<table>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" id="dns" name="services[dns]" checked>
	</td>
	<td>
	<b>DNS Resolution</b><br>
	Monitors the FQDN to ensure it resolves to a valid IP address.<br><br>
	</td>
	</tr>
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" id="dnsip" name="services[dnsip]" checked>
	</td>
	<td>
	<b>DNS IP Match</b><br>
	Monitors the FQDN to ensure it resolves to the current known IP address.  Helps ensure your DNS doesn\'t change unexpectedly, which may mean a security breach has occurred.<br><br>
	</td>
	</tr>

	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$ip=grab_array_var($inargs,"ip");
			$hostname=grab_array_var($inargs,"hostname");
			
			$dnsserver=grab_array_var($inargs,"dnsserver");
			$dnsauthority=grab_array_var($inargs,"dnsauthority");

			$services=grab_array_var($inargs,"services",array());
			$serviceargs=grab_array_var($inargs,"serviceargs",array());
			
		
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]="Invalid host name.";
			/*
			if(array_key_exists("transfer",$services)){
				if($username=="" || $password=="")
					$errmsg[$errors++]="Username or password is blank.";
				if($port=="")
					$errmsg[$errors++]="Invalid port number.";
				}
			*/
			
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$ip=grab_array_var($inargs,"ip");
			$hostname=grab_array_var($inargs,"hostname");
			
			$dnsserver=grab_array_var($inargs,"dnsserver");
			$dnsauthority=grab_array_var($inargs,"dnsauthority");

			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">
		<input type="hidden" name="hostname" value="'.htmlentities($hostname).'">
		<input type="hidden" name="ip" value="'.htmlentities($ip).'">
		<input type="hidden" name="dnsserver" value="'.htmlentities($dnsserver).'">
		<input type="hidden" name="dnsauthority" value="'.htmlentities($dnsauthority).'">
		<input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'">
		<input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'">
		
		<!--SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR>-->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			
			$output='
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$ip=grab_array_var($inargs,"ip","");
			$address=grab_array_var($inargs,"address","");

			// this is different than normal
			$hostaddress=$ip;
			
			$dnsserver=grab_array_var($inargs,"dnsserver");
			$dnsauthority=grab_array_var($inargs,"dnsauthority");

			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			/*
			echo "SERVICES<BR>";
			print_r($services);
			echo "<BR>";
			echo "SERVICEARGS<BR>";
			print_r($serviceargs);
			echo "<BR>";
			*/
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["ip"]=$ip;
			$meta_arr["dnsserver"]=$dnsserver;
			$meta_arr["dnsauthority"]=$dnsauthority;
			$meta_arr["services"]=$services;
			$meta_arr["serivceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			$objs=array();
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_dnsquery_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => "server.png",
					"statusmap_image" => "server.png",
					"_xiwizard" => $wizard_name,
					);
				}
				
			$pluginopts="";
			if($dnsserver!=""){
				$pluginopts.=" -s ".$dnsserver;
				if($dnsauthority!="")
					$pluginopts.=" -A";
				}
				
			// see which services we should monitor
			foreach($services as $svc => $svcstate){
			
				//echo "PROCESSING: $svc -> $svcstate<BR>\n";
		
				switch($svc){
				
					case "dns":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "DNS Resolution - ".$address,
							"use" => "xiwizard_dnsquery_service",
							"check_command" => "check_xi_service_dnsquery!-H ".$address.$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "dnsip":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "DNS IP Match - ".$address,
							"use" => "xiwizard_dnsquery_service",
							"check_command" => "check_xi_service_dnsquery!-H ".$address." -a ".$ip.$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
					
					default:
						break;
					}
				}

			//echo "OBJECTS:<BR>";
			//print_r($objs);
			//exit();
					
			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	

?>